@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (c) 2011-2020, Cédric Krier
-# Copyright (c) 2013-2014, Nicolas Évrard
-# Copyright (c) 2011-2020, B2CK
+# Copyright (c) 2013-2021, Nicolas Évrard
+# Copyright (c) 2011-2021, B2CK
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -36,11 +36,15 @@ from threading import local, currentThread
 from collections import defaultdict
 from itertools import chain
 
-__version__ = '1.2.1'
+__version__ = '1.2.2'
 __all__ = ['Flavor', 'Table', 'Values', 'Literal', 'Column', 'Join',
     'Asc', 'Desc', 'NullsFirst', 'NullsLast', 'format2numeric']
 
 
+def _escape_identifier(name):
+    return '"%s"' % name.replace('"', '""')
+
+
 def alias(i, letters=string.ascii_lowercase):
     '''
     Generate a unique alias based on integer
@@ -735,21 +739,19 @@ class Insert(WithQuery):
         if self.columns:
             assert all(col.table == self.table for col in self.columns)
             columns = ' (' + ', '.join(map(str, self.columns)) + ')'
-        if isinstance(self.values, Query):
-            values = ' %s' % str(self.values)
-            # TODO manage DEFAULT
-        elif self.values is None:
-            values = ' DEFAULT VALUES'
         with AliasManager():
-            table = self.table
-            AliasManager.set(table, str(table)[1:-1])
+            if isinstance(self.values, Query):
+                values = ' %s' % str(self.values)
+                # TODO manage DEFAULT
+            elif self.values is None:
+                values = ' DEFAULT VALUES'
             returning = ''
             if self.returning:
                 returning = ' RETURNING ' + ', '.join(
                     map(self._format, self.returning))
             return (self._with_str()
-                + 'INSERT INTO %s' % self.table + columns
-                + values + returning)
+                + 'INSERT INTO %s AS "%s"' % (self.table, self.table.alias)
+                + columns + values + returning)
 
     @property
     def params(self):
@@ -804,11 +806,7 @@ class Update(Insert):
         with AliasManager():
             from_ = ''
             if self.from_:
-                table = From([self.table])
                 from_ = ' FROM %s' % str(self.from_)
-            else:
-                table = self.table
-                AliasManager.set(table, str(table)[1:-1])
             values = ', '.join('%s = %s' % (c, self._format(v))
                 for c, v in zip(columns, self.values))
             where = ''
@@ -819,8 +817,8 @@ class Update(Insert):
                 returning = ' RETURNING ' + ', '.join(
                     map(self._format, self.returning))
             return (self._with_str()
-                + 'UPDATE %s SET ' % table + values + from_
-                + where + returning)
+                + 'UPDATE %s AS "%s" SET ' % (self.table, self.table.alias)
+                + values + from_ + where + returning)
 
     @property
     def params(self):
@@ -970,13 +968,8 @@ class Table(FromItem):
         self._database = database
 
     def __str__(self):
-        if self._database:
-            return '"%s"."%s"."%s"' % (
-                self._database, self._schema, self._name)
-        elif self._schema:
-            return '"%s"."%s"' % (self._schema, self._name)
-        else:
-            return '"%s"' % self._name
+        return '.'.join(map(_escape_identifier, filter(None,
+                    (self._database, self._schema, self._name))))
 
     @property
     def params(self):
@@ -1354,16 +1347,13 @@ class Column(Expression):
         return self._name
 
     def __str__(self):
-        if self._name == '*':
-            t = '%s'
-        else:
-            t = '"%s"'
+        name = (self._name if self._name == '*'
+            else _escape_identifier(self._name))
         alias = self._from.alias
         if alias:
-            t = '"%s".' + t
-            return t % (alias, self._name)
+            return '%s.%s' % (_escape_identifier(alias), name)
         else:
-            return t % self._name
+            return name
 
     @property
     def params(self):
@@ -1379,7 +1369,7 @@ class As(Expression):
         self.output_name = output_name
 
     def __str__(self):
-        return '"%s"' % self.output_name
+        return '%s' % _escape_identifier(self.output_name)
 
     @property
     def params(self):
