@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (c) 2011-2013, Cédric Krier
-# Copyright (c) 2011-2013, B2CK
+# Copyright (c) 2021, Nicolas Évrard
+# Copyright (c) 2011-2021, B2CK
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -36,12 +37,12 @@ class TestUpdate(unittest.TestCase):
 
     def test_update1(self):
         query = self.table.update([self.table.c], ['foo'])
-        self.assertEqual(str(query), 'UPDATE "t" SET "c" = %s')
+        self.assertEqual(str(query), 'UPDATE "t" AS "a" SET "c" = %s')
         self.assertEqual(query.params, ('foo',))
 
         query.where = (self.table.b == Literal(True))
         self.assertEqual(str(query),
-            'UPDATE "t" SET "c" = %s WHERE ("t"."b" = %s)')
+            'UPDATE "t" AS "a" SET "c" = %s WHERE ("a"."b" = %s)')
         self.assertEqual(query.params, ('foo', True))
 
     def test_update2(self):
@@ -60,15 +61,15 @@ class TestUpdate(unittest.TestCase):
         query_nolist = t1.update([t1.c], t2.select(t2.c, where=t2.i == t1.i))
         for query in [query_list, query_nolist]:
             self.assertEqual(str(query),
-                'UPDATE "t1" SET "c" = ('
-                'SELECT "b"."c" FROM "t2" AS "b" WHERE ("b"."i" = "t1"."i"))')
+                'UPDATE "t1" AS "b" SET "c" = ('
+                'SELECT "a"."c" FROM "t2" AS "a" WHERE ("a"."i" = "b"."i"))')
             self.assertEqual(query.params, ())
 
     def test_update_returning(self):
         query = self.table.update([self.table.c], ['foo'],
             returning=[self.table.c])
         self.assertEqual(str(query),
-            'UPDATE "t" SET "c" = %s RETURNING "t"."c"')
+            'UPDATE "t" AS "a" SET "c" = %s RETURNING "a"."c"')
         self.assertEqual(query.params, ('foo',))
 
     def test_update_returning_select(self):
@@ -78,9 +79,9 @@ class TestUpdate(unittest.TestCase):
             returning=[
                 t2.select(t2.c, where=(t2.c1 == t1.c) & (t2.c2 == 'bar'))])
         self.assertEqual(str(query),
-            'UPDATE "t1" SET "c" = %s '
-            'RETURNING (SELECT "b"."c" FROM "t2" AS "b" '
-            'WHERE (("b"."c1" = "t1"."c") AND ("b"."c2" = %s)))')
+            'UPDATE "t1" AS "b" SET "c" = %s '
+            'RETURNING (SELECT "a"."c" FROM "t2" AS "a" '
+            'WHERE (("a"."c1" = "b"."c") AND ("a"."c2" = %s)))')
         self.assertEqual(query.params, ('foo', 'bar'))
 
     def test_with(self):
@@ -92,16 +93,17 @@ class TestUpdate(unittest.TestCase):
             with_=[w],
             values=[w.select(w.c3, where=w.c4 == 2)])
         self.assertEqual(str(query),
-            'WITH "b" AS (SELECT "c"."c1" FROM "t1" AS "c") '
-            'UPDATE "t" SET "c2" = (SELECT "b"."c3" FROM "b" AS "b" '
-            'WHERE ("b"."c4" = %s))')
+            'WITH "a" AS (SELECT "b"."c1" FROM "t1" AS "b") '
+            'UPDATE "t" AS "c" SET "c2" = (SELECT "a"."c3" FROM "a" AS "a" '
+            'WHERE ("a"."c4" = %s))')
         self.assertEqual(query.params, (2,))
 
     def test_schema(self):
         t1 = Table('t1', 'default')
         query = t1.update([t1.c1], ['foo'])
 
-        self.assertEqual(str(query), 'UPDATE "default"."t1" SET "c1" = %s')
+        self.assertEqual(
+            str(query), 'UPDATE "default"."t1" AS "a" SET "c1" = %s')
         self.assertEqual(query.params, ('foo',))
 
     def test_schema_subselect(self):
@@ -110,7 +112,7 @@ class TestUpdate(unittest.TestCase):
         query = t1.update([t1.c1], t2.select(t2.c, where=t2.i == t1.i))
 
         self.assertEqual(str(query),
-            'UPDATE "default"."t1" SET "c1" = ('
-            'SELECT "b"."c" FROM "default"."t2" AS "b" '
-            'WHERE ("b"."i" = "default"."t1"."i"))')
+            'UPDATE "default"."t1" AS "b" SET "c1" = ('
+            'SELECT "a"."c" FROM "default"."t2" AS "a" '
+            'WHERE ("a"."i" = "b"."i"))')
         self.assertEqual(query.params, ())
